@@ -14,4 +14,4 @@ def auto_validate(defintion: DefinitionInput) -> DefinitionFragment:
 
     """
 
-    return DefinitionFragment(id=random.randint(0, 700), **defintion.dict())
+    return DefinitionFragment(**defintion.dict())
